@@ -8,7 +8,16 @@ Interchange6::Schema::Result::OrderComment
 
 =cut
 
-use Interchange6::Schema::Candy;
+use strict;
+use warnings;
+
+use base 'DBIx::Class::Core';
+
+=head1 TABLE: C<order_comments>
+
+=cut
+
+__PACKAGE__->table("order_comments");
 
 =head1 DESCRIPTION
 
@@ -24,11 +33,6 @@ Link table between Order and Message for order comments.
   is_foreign_key: 1
   is_nullable: 0
 
-=cut
-
-column messages_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
-
 =head2 orders_id
 
   data_type: 'integer'
@@ -37,8 +41,12 @@ column messages_id =>
 
 =cut
 
-column orders_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
+__PACKAGE__->add_columns(
+    "messages_id",
+    { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
+    "orders_id",
+    { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
+);
 
 =head1 PRIMARY KEY
 
@@ -52,7 +60,7 @@ column orders_id =>
 
 =cut
 
-primary_key "messages_id", "orders_id";
+__PACKAGE__->set_primary_key( "messages_id", "orders_id" );
 
 =head1 RELATIONS
 
@@ -64,10 +72,12 @@ Related object: L<Interchange6::Schema::Result::Message>
 
 =cut
 
-belongs_to
-  message => "Interchange6::Schema::Result::Message",
-  "messages_id",
-  { cascade_delete => 1 };
+__PACKAGE__->belongs_to(
+    "message",
+    "Interchange6::Schema::Result::Message",
+    "messages_id",
+    { cascade_delete => 1 },
+);
 
 =head2 order
 
@@ -77,8 +87,10 @@ Related object: L<Interchange6::Schema::Result::Order>
 
 =cut
 
-belongs_to
-  order => "Interchange6::Schema::Result::Order",
-  "orders_id";
+__PACKAGE__->belongs_to(
+    "order",
+    "Interchange6::Schema::Result::Order",
+    "orders_id",
+);
 
 1;
