@@ -20,6 +20,20 @@ __PACKAGE__->load_components(qw(InflateColumn::DateTime TimeStamp));
 
 __PACKAGE__->table("shipment_rates");
 
+=head1 DESCRIPTION
+
+In the context of shipment the rate is the value give for a shipping method based on
+desination zone_id and weight.
+
+=over 4
+
+=item * Flat rate shipping
+
+If min_weight and max_weight are set to 0 for a shipping method and zone flate rate will be
+assumed.  If min_weight is set and max_weight is 0 max weight is assumed as infinite.
+
+=back
+
 =head1 ACCESSORS
 
 =head2 shipment_rates_id
@@ -34,7 +48,20 @@ __PACKAGE__->table("shipment_rates");
   is_foreign_key: 1
   is_nullable: 0
 
-=head2 weight
+=head2 shipment_methods_id
+
+  data_type: 'integer'
+  is_foreign_key: 1
+  is_nullable: 0
+
+=head2 min_weight
+
+  data_type: 'numeric'
+  default_value: 0.0
+  is_nullable: 0
+  size: [10,2]
+
+=head2 max_weight
 
   data_type: 'numeric'
   default_value: 0.0
@@ -72,7 +99,11 @@ __PACKAGE__->add_columns(
   },
   "zones_id",
   { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
-  "weight",
+  "shipment_methods_id",
+  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
+  "min_weight",
+  { data_type => "numeric", default_value => "0.0", is_nullable => 0, size => [10, 2] },
+  "max_weight",
   { data_type => "numeric", default_value => "0.0", is_nullable => 0, size => [10, 2] },
   "price",
   {
@@ -101,7 +132,7 @@ __PACKAGE__->set_primary_key("shipment_rates_id");
 
 =head1 RELATIONS
 
-=head2 Zone
+=head2 zone
 
 Type: belongs_to
 
@@ -110,11 +141,25 @@ Related object: L<Interchange6::Schema::Result::Zone>
 =cut
 
 __PACKAGE__->belongs_to(
-  "Zone",
+  "zone",
   "Interchange6::Schema::Result::Zone",
   { zones_id => "zones_id" },
   { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
 );
 
+=head2 shipment_method
+
+Type: belongs_to
+
+Related object: L<Interchange6::Schema::Result::ShipmentMethod>
+
+=cut
+
+__PACKAGE__->belongs_to(
+  "shipment_method",
+  "Interchange6::Schema::Result::ShipmentMethod",
+  { shipment_methods_id => "shipment_methods_id" },
+  { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
+);
 
 1;
