@@ -8,6 +8,7 @@ eval "use DBD::SQLite";
 plan skip_all => "DBD::SQLite required" if $@;
 
 sub _build_database {
+
     # does nothing atm for SQLite
     return;
 }
@@ -18,9 +19,16 @@ sub _build_dbd_version {
 
 sub connect_info {
     my $self = shift;
+
     # :memory: db only for now
     return ( "dbi:SQLite:dbname=:memory:", undef, undef,
-        { on_connect_call => 'use_foreign_keys' } );
+        { sqlite_unicode => 1, on_connect_call => 'use_foreign_keys' } );
+}
+
+sub _build_database_info {
+    my $self = shift;
+    return "SQLite library version: "
+      . $self->schema->storage->dbh->{sqlite_version};
 }
 
 1;
