@@ -1,6 +1,7 @@
 package Test::Navigation;
 
 use Test::Exception;
+use Test::More;
 use Test::Roo::Role;
 
 test 'navigation tests' => sub {
@@ -9,29 +10,42 @@ test 'navigation tests' => sub {
 
     my $self = shift;
 
-    # prereqs
-    $self->navigation unless $self->has_navigation;
+    my ( $navlist, $nav_product );
 
-    my ( $nav, $navlist, $nav_product );
+    my $product = $self->products->first;
 
-    my $product = $self->products->find('os28077');
+    my @path = (
+        { name => 'Flowers', uri => 'Flowers' },
+        { name => 'Tulips',  uri => 'Flowers/Tulips' },
+    );
+
+    lives_ok( sub { $navlist = navigation_make_path( $self->schema, \@path ) },
+        "Create navlist" );
+
+    cmp_ok( scalar(@$navlist), '==', 2, "Number of navigation items created." );
+
+    cmp_ok( $navlist->[1]->parent_id,
+        '==', $navlist->[0]->id, "Correct parent for second navigation item" );
+
+    lives_ok(
+        sub {
+            $nav_product =
+              $self->schema->resultset('NavigationProduct')
+              ->create(
+                { navigation_id => $navlist->[1]->id, sku => $product->sku } );
+        },
+        "Create navigation_product"
+    );
 
     my @product_path = $product->path;
 
     cmp_ok( scalar(@product_path), '==', 2, "Length of path for product" );
 
     cmp_ok( $product_path[0]->uri,
-        'eq', 'tool-storage', "1st branch URI for product" );
+        'eq', 'Flowers', "1st branch URI for product" );
 
     cmp_ok( $product_path[1]->uri,
-        'eq', 'tool-storage/tool-belts', "2nd branch URI for product" );
-
-    cmp_ok(
-        $product_path[1]->parent_id,
-        '==',
-        $product_path[0]->id,
-        "Correct parent for second navigation item"
-    );
+        'eq', 'Flowers/Tulips', "2nd branch URI for product" );
 
     # also check in scalar context
 
@@ -40,14 +54,14 @@ test 'navigation tests' => sub {
     cmp_ok( scalar(@$product_path), '==', 2, "Length of path for product" );
 
     cmp_ok( $product_path->[0]->uri,
-        'eq', 'tool-storage', "1st branch URI for product" );
+        'eq', 'Flowers', "1st branch URI for product" );
 
     cmp_ok( $product_path->[1]->uri,
-        'eq', 'tool-storage/tool-belts', "2nd branch URI for product" );
+        'eq', 'Flowers/Tulips', "2nd branch URI for product" );
 
     # add product to country navigation
 
-    my @path = (
+    @path = (
         {
             name => 'South America',
             uri  => 'South-America',
@@ -56,7 +70,7 @@ test 'navigation tests' => sub {
         { name => 'Chile', uri => 'South-America/Chile', type => 'country' },
     );
 
-    lives_ok( sub { $navlist = navigation_make_path( $self->ic6s_schema, \@path ) },
+    lives_ok( sub { $navlist = navigation_make_path( $self->schema, \@path ) },
         "Create country navlist" );
 
     cmp_ok( scalar(@$navlist), '==', 2,
@@ -65,23 +79,16 @@ test 'navigation tests' => sub {
     lives_ok(
         sub {
             $nav_product =
-              $self->ic6s_schema->resultset('NavigationProduct')
+              $self->schema->resultset('NavigationProduct')
               ->create(
                 { navigation_id => $navlist->[1]->id, sku => $product->sku } );
         },
         "Create navigation_product"
     );
 
-    # we should get the primary path since fixtures sets higher prio for this
-
     @product_path = $product->path;
 
-    cmp_ok( scalar(@product_path), '==', 2, "Length of path for product" );
-
-    cmp_ok( $product_path[0]->uri,
-        'eq', 'tool-storage', "1st branch URI for product" );
-
-    # now the country path
+    cmp_ok( scalar(@product_path), '==', 0, "Length of path for product" );
 
     @product_path = $product->path('country');
 
@@ -93,20 +100,21 @@ test 'navigation tests' => sub {
     cmp_ok( $product_path[1]->uri,
         'eq', 'South-America/Chile', "path[1] is correct" );
 
-    lives_ok(
-        sub {
-            $nav = $self->navigation->find( { uri => 'hand-tools/hammers' } );
-        },
-        "find nav hand-tools/hammers"
-    );
+    cmp_ok( $self->schema->resultset('Navigation')->count,
+        '==', 4, "4 Navigation rows" );
 
-    cmp_ok( $nav->siblings->count, "==", 8, "nav has 8 siblings" );
+    cmp_ok( $self->schema->resultset('NavigationProduct')->count,
+        '==', 2, "2 NavigationProduct rows" );
 
-    cmp_ok( $nav->siblings_with_self->count, "==", 9,
-        "9 siblings with self" );
+    lives_ok( sub { $self->schema->resultset('Navigation')->delete_all },
+        "delete all Navigation rows" );
+
+    cmp_ok( $self->schema->resultset('Navigation')->count,
+        '==', 0, "0 Navigation rows" );
+
+    cmp_ok( $self->schema->resultset('NavigationProduct')->count,
+        '==', 0, "0 NavigationProduct rows" );
 
-    # cleanup
-    $self->clear_navigation;
 };
 
 sub navigation_make_path {
